Google Meet Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Google Meet Baseline Report

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## MEET-1 Meeting Access

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.1.1v0.5 | Meeting access SHOULD be restricted to users signed in with a Google Account or Dialing in using a phone. | Warning | Should | The following OUs are non-compliant: Cool Example Org: Who can join meetings is set to: all users (including users not signed in with a Google account)

## MEET-2 Internal Access to External Meetings

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.2.1v0.5 | Meeting access SHALL be disabled for meetings created by users who are not members of any Google Workspace tenant or organization. | Pass | Shall | Requirement met in all OUs and groups.

## MEET-3 Host Management Meeting Features

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.3.1v0.5 | Host Management meeting features SHALL be enabled. | Pass | Shall | Requirement met in all OUs and groups.

## MEET-4 External Participants

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.4.1v0.5 | Warn for external participants SHALL be enabled. | Pass | Shall | Requirement met in all OUs and groups.

## MEET-5 Incoming Calls

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.5.1v0.5 | Incoming calls SHALL be restricted to contacts and other users in the organization. | No events found | Shall | No relevant event in the current logs for the top-level OU, Cool Example Org. While we are unable to determine the state from the logs, the default setting is compliant; manual check recommended. Log-based check. See limitations.

## MEET-6 Video Meeting Settings

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.MEET.6.1v0.5 | Automatic recordings for Google Meet SHALL be disabled. | N/A | Shall/Not-Implemented | Currently not able to be tested automatically; please manually check.
GWS.MEET.6.2v0.5 | Automatic transcripts for Google Meet SHALL be disabled. | N/A | Shall/Not-Implemented | Currently not able to be tested automatically; please manually check.